/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch das
 * Ministerium für Energiewende, Klimaschutz, Umwelt und Natur
 * Zentrales IT-Management
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.formcycle;

import java.util.List;
import java.util.Locale;
import java.util.Map;

import de.xima.fc.entities.Benutzer;
import de.xima.fc.entities.Mandant;
import de.xima.fc.entities.Projekt;
import de.xima.fc.entities.Vorgang;
import de.xima.fc.workflow.event.AFormRecordEventData;

/**
 * Custom event for the workflow trigger that is initiated by the HTTP servlet action plugin when an HTTP request is
 * made.
 * @author unspecified
 */
@SuppressWarnings("serial")
public final class WorkflowElementEvent extends AFormRecordEventData {
  private final String type;
  private final Map<String, List<String>> requestParams;

  /**
   * Creates a new event data instance with the given data.
   * @param client Client who owns the form record.
   * @param user User who initiated the event.
   * @param locale Request locale to use for locale-sensitive operations.
   * @param project Project to which the form record belongs.
   * @param formRecord Form record for which to trigger events.
   * @param type Custom type of the event, a workflow trigger reacts only to a given type.
   * @param requestParams HTTP parameters of the request that triggered this event.
   */
  public WorkflowElementEvent(Mandant client, Benutzer user, Locale locale, Projekt project, Vorgang formRecord, String type, Map<String, List<String>> requestParams) {
    super(client, user, locale, project, formRecord);
    this.requestParams = requestParams;
    this.type = type;
  }
  
  /**
   * @return HTTP parameters of the request that triggered this event.
   */
  public Map<String, List<String>> getRequestParams() {
    return requestParams;
  }

  /**
   * @return The type of this event. A trigger only reacts to a specific type.
   */
  public String getType() {
    return type;
  }

  @Override
  public Boolean isAnonymize() {
    return false;
  }
}
