/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch das
 * Ministerium für Energiewende, Klimaschutz, Umwelt und Natur
 * Zentrales IT-Management
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.formcycle;

import java.util.Properties;
import java.util.concurrent.atomic.AtomicReference;

import javax.faces.view.ViewScoped;
import javax.inject.Named;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import de.xima.fc.interfaces.plugin.lifecycle.IPluginInitializeBeanData;
import de.xima.fc.interfaces.plugin.lifecycle.helper.IPluginFileHelper;
import de.xima.fc.interfaces.plugin.lifecycle.helper.IPluginResourceHelper;
import de.xima.fc.plugin.exception.FCPluginException;
import de.xima.fc.workflow.mixin.INodePropertyPluginBean;

/**
 * Controller bean for the custom UI when editing the properties of the workflow node.
 * A bean is not required, often it suffices to add an XHTML page without a bean. This
 * class is a stub that that you can expand when you do not a bean, such as when you
 * want to enrich your UI with AJAX-enhanced logic.
 * @author unspecified
 */
@Named
@ViewScoped
public final class WorkflowElementNodeBean implements INodePropertyPluginBean<WorkflowElementNodeProps> {

  private static final Logger LOG = LoggerFactory.getLogger(WorkflowElementNodeBean.class);

  private transient AtomicReference<IPluginInitializeBeanData> initializeBeanData;

  /**
   * A method that could be used the the action for some command button in your UI.
   */
  public void controllerAction() {
    // Add custom logic here when the button was pressed...
    LOG.info("Controller action was called");
  }
  
  @Override
  public IPluginFileHelper getFileHelper() {
    return initializeBeanData.get().getFileHelper();
  }

  @Override
  public Properties getProperties() {
    return initializeBeanData.get().getProperties();
  }

  @Override
  public IPluginResourceHelper getResourceHelper() {
    return initializeBeanData.get().getResourceHelper();
  }

  @Override
  public void initialize(IPluginInitializeBeanData initializeBeanData) throws FCPluginException {
    this.initializeBeanData = new AtomicReference<>(initializeBeanData);
  }
}
