/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch das
 * Ministerium für Energiewende, Klimaschutz, Umwelt und Natur
 * Zentrales IT-Management
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.formcycle;

import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.Size;

import de.ozgcloud.formcycle.validation.ConditionalNotEmpty;
import de.xima.fc.workflow.taglib.model.BaseActionProps;
import lombok.Getter;
import lombok.Setter;

/**
 * A POJO (plain old Java object) that contains the data the user can edit in
 * the workflow action UI.
 * <p>
 * All fields in this class are for illustration purposes only, you should
 * remove them and add whatever properties you need for your use case.
 * <p>
 * Validation is done via constraint annotation of the Bean Validation API. You
 * should not use any other JSF validators in the XHTML page, such as
 * {@code required} attributes.
 * <p>
 * This shows a simple String and boolean field. Also demonstrates how a file
 * and one or more user groups can be selected
 * 
 * @author unspecified
 */
@SuppressWarnings("serial")
@Getter
@Setter
@ConditionalNotEmpty(
		dependingOn = "useCustomEingangsAdapterUrl",
		withValues = {"true"},
		requiredProperties = {"eingangsAdapterUrl"}
)
public final class WorkflowElementNodeProps extends BaseActionProps {

	@NotEmpty
	@Size(max = 20)
	private String organisationsEinheitId;

	private boolean useCustomEingangsAdapterUrl;

	private String eingangsAdapterUrl;

}
