/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch das
 * Ministerium für Energiewende, Klimaschutz, Umwelt und Natur
 * Zentrales IT-Management
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.formcycle;

import static org.assertj.core.api.Assertions.*;

import java.io.IOException;
import java.time.ZonedDateTime;
import java.util.Collections;

import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import de.ozgcloud.eingang.formcycle.FormCycleAttachmentGroup;
import de.ozgcloud.eingang.formcycle.FormCycleConfirmationResponse;
import de.ozgcloud.eingang.formcycle.FormCycleFormData;
import de.ozgcloud.eingang.formcycle.FormCycleFormHeader;
import de.ozgcloud.eingang.formcycle.FormCycleServiceKonto;
import de.ozgcloud.vorgang.vorgang.GrpcFormData;

class OzgCloudFormDataHttpClientITCase {

	private static final Logger LOG = LoggerFactory.getLogger(OzgCloudFormDataHttpClientITCase.class);

	@Test
	@Disabled("Test sollte nur manuell ausgeführt werden, da die Daten in ein Dev System eingeliefert werden")
	void testReal() throws IOException {

		String url = "https://fuerth-formcycle.dev.by.ozg-cloud.de/formData";

		OzgCloudFormDataHttpClient client = new OzgCloudFormDataHttpClient(OzgCloudConfig.builder()
				.eingangsAdapterUrl(url).build(), new SystemPropertiesProvider());

		FormCycleConfirmationResponse response = client.send(createTestFormData(), Collections.emptyList(), Collections.emptyList());

		LOG.info("FormDataResponse Vorgangsnummer: " + response.getVorgangNummer());

		assertThat(response.getVorgangNummer()).isNotEmpty();
	}

	private FormCycleFormData createTestFormData() {
		return FormCycleFormData.newBuilder()
				.setHeader(FormCycleFormHeader.newBuilder().setFormName("Schnitzel").setReceivedAt(ZonedDateTime.now().toString()).build())
				.setServiceKonto(FormCycleServiceKonto.newBuilder().build())
				.setFormData(GrpcFormData.newBuilder().build())
				.addAttachmentGroup(FormCycleAttachmentGroup.newBuilder()
						.setName("Klaus")
						.addFileId("Vendor")
						.build())
				.build();
	}
}
